@@ -56,6 +56,7 @@ unsigned long   gcc1, gcc2;
 int             txtx1, txty1, txtx2 = 8, txty2 = 40, txty3 = 0;
 
 bool            withdrawn = TRUE;
+bool            force_shaped = FALSE;
 bool            sigHUP = FALSE;
 struct allInfo  *aiPtr = 0;
 
@@ -397,7 +398,7 @@ void            initializeAppIcon()
     disp = XCreatePixmap(dpy, Root, 64, 64, DefaultDepth(dpy, DefaultScreen(dpy)));
 
     /* Install mask or copy background tile */
-    if (withdrawn)
+    if (withdrawn || force_shaped)
         XShapeCombineMask(dpy, Win[activeWin], ShapeBounding, 0, 0, mask,
                 ShapeSet);
     else
@@ -519,6 +520,8 @@ void            printHelp(int argc, char *argv[])
     fprintf(stderr, "   -h | -help             display this help screen\n");
     fprintf(stderr, "   -i                     ignore NFS mounts\n");
     fprintf(stderr, "   -n                     wm other than Window Maker\n");
+    fprintf(stderr, "   -s                     shaped window even if -n is"
+        " enabled.\n");
     fprintf(stderr, "   -display display       select target display"
         " (see X manual pages)\n\n");
     exit(0);
@@ -529,7 +532,7 @@ void            scanArgs(int argc, char *argv[])
     int             optchar;
     int             disp_set = 0;
 
-    while ((optchar = getopt(argc, argv, "hind:")) != EOF)
+    while ((optchar = getopt(argc, argv, "hinsd:")) != EOF)
     {
         disp_set = 0;
         switch (optchar)
@@ -540,6 +543,9 @@ void            scanArgs(int argc, char *argv[])
         case 'i':
             ignoreNFS = TRUE;
             break;
+        case 's':
+            force_shaped = TRUE;
+            break;
         case 'd':
             if (!strcmp(optarg, "isplay"))
                 disp_set++;
@@ -708,10 +714,33 @@ void            pressEvent(XButtonEvent * xev, allInfo * ai)
             if (mp->isMounted)
             {
                 mp->performEject = mp->ejectFlag && (xev->button == Button1);
+
+                if (xev->button == Button3)
+                {
+                    mp->performEject = 1;
+                }
                 internalUmount(mp);
             }
             else
-                internalMount(mp);
+            {
+                if (xev->button == Button3)
+                {
+                    /* eject! */
+                    if (ejectcmd[0] == 0)
+                        internalEject(mp);
+                    else
+                    {
+                        char    cmd[256];
+                        int        n = (sizeof(cmd) / sizeof(cmd[0]));
+
+                        snprintf(cmd, n, ejectcmd, mp->mountStr);
+                        cmd[n - 1] = '\0';
+                        newSystem(cmd, mp);
+                    }
+                }
+                else
+                    internalMount(mp);
+            }
         }
         else
         {
